# nbstore

[![PyPI Version][pypi-v-image]][pypi-v-link]
[![Python Version][python-v-image]][python-v-link]
[![Build Status][GHAction-image]][GHAction-link]
[![Coverage Status][codecov-image]][codecov-link]

nbstore is a tool for storing and managing images and other files in Jupyter notebooks.

<!-- Badges -->
[pypi-v-image]: https://img.shields.io/pypi/v/nbstore.svg
[pypi-v-link]: https://pypi.org/project/nbstore/
[python-v-image]: https://img.shields.io/pypi/pyversions/nbstore.svg
[python-v-link]: https://pypi.org/project/nbstore
[GHAction-image]: https://github.com/daizutabi/nbstore/actions/workflows/ci.yaml/badge.svg?branch=main&event=push
[GHAction-link]: https://github.com/daizutabi/nbstore/actions?query=event%3Apush+branch%3Amain
[codecov-image]: https://codecov.io/github/daizutabi/nbstore/coverage.svg?branch=main
[codecov-link]: https://codecov.io/github/daizutabi/nbstore?branch=main
